@@ -47,12 +47,13 @@
 
 static void generateMidColor(GdkColor *a, GdkColor *b, GdkColor *mid, double factor);
 
-static int strcmp_i(const char *s1, const char *s2)
+static int strncmp_i(const char *s1, const char *s2, int num)
 {
     char c1,
          c2;
+    int  i;
 
-    for(;;)
+    for(i=0; -1==num || i<num; ++i)
     {
         c1=*s1++;
         c2=*s2++;
@@ -68,6 +69,8 @@ static int strcmp_i(const char *s1, const char *s2)
     return (int)c2-(int)c1;
 }
 
+#define strcmp_i(A, B) strncmp_i(A, B, -1)
+
 struct QtIcons
 {
     int smlTbSize,
@@ -91,6 +94,10 @@ enum QtColorRoles
     COLOR_TEXT_SELECTED,
     COLOR_BUTTON_TEXT,
     COLOR_LV,
+
+    COLOR_TOOLTIP,
+    COLOR_TOOLTIP_TEXT,
+
     COLOR_NONE,
     COLOR_NUMCOLORS=COLOR_NONE  /* NONE does not count! */
 };
@@ -99,12 +106,14 @@ typedef enum
 {
     GTK_APP_UNKNOWN,
     GTK_APP_MOZILLA,
+    GTK_APP_NEW_MOZILLA, /* For firefox3 */
     GTK_APP_OPEN_OFFICE,
     GTK_APP_VMPLAYER,
     GTK_APP_GIMP,
     GTK_APP_GIMP_PLUGIN,
     GTK_APP_JAVA,
-    GTK_APP_JAVA_SWT
+    /*GTK_APP_JAVA_SWT,*/
+    GTK_APP_EVOLUTION
     /*GTK_APP_GAIM*/
 } EGtkApp;
 
@@ -130,7 +139,8 @@ struct QtData
                     *styleName;
     GtkToolbarStyle toolbarStyle;
     struct QtIcons  iconSizes;
-    gboolean        buttonIcons;
+    gboolean        buttonIcons,
+                    shadeSortedList;
     EGtkApp         app;
     gboolean        qt4;
 };
@@ -158,6 +168,11 @@ struct QtData
 
 struct QtData qtSettings;
 
+static gboolean isMozilla()
+{
+    return GTK_APP_MOZILLA==qtSettings.app || GTK_APP_NEW_MOZILLA==qtSettings.app;
+}
+
 static gboolean useQt3Settings()
 {
     static const char *vers=NULL;
@@ -240,7 +255,8 @@ enum
     RD_BUTTON_ICONS      = 0x0080,
     RD_SMALL_ICON_SIZE   = 0x0100,
     RD_LIST_COLOR        = 0x0200,
-    RD_STYLE             = 0x0400
+    RD_STYLE             = 0x0400,
+    RD_LIST_SHADE        = 0x0800
 };
 
 static char * getKdeHome()
@@ -271,15 +287,15 @@ static char * getKdeHome()
     return kdeHome;
 }
 
-static char * themeFile(const char *prefix, const char *name, char **tmpStr)
+static char * themeFileSub(const char *prefix, const char *name, char **tmpStr, const char *sub)
 {
-    *tmpStr=realloc(*tmpStr, strlen(prefix)+1+strlen(QTC_THEME_DIR)+1+strlen(name)+strlen(QTC_THEME_SUFFIX)+1);
+    *tmpStr=realloc(*tmpStr, strlen(prefix)+1+strlen(sub)+1+strlen(name)+strlen(QTC_THEME_SUFFIX)+1);
 
     if(*tmpStr)
     {
         struct stat st;
 
-        sprintf(*tmpStr, "%s/%s/%s%s", prefix, QTC_THEME_DIR, name, QTC_THEME_SUFFIX);
+        sprintf(*tmpStr, "%s/%s/%s%s", prefix, sub, name, QTC_THEME_SUFFIX);
 
         if(0==stat(*tmpStr, &st))
             return *tmpStr;
@@ -288,6 +304,16 @@ static char * themeFile(const char *prefix, const char *name, char **tmpStr)
     return NULL;
 }
 
+static char * themeFile(const char *prefix, const char *name, char **tmpStr)
+{
+    char *f=themeFileSub(prefix, name, tmpStr, QTC_THEME_DIR);
+
+    if(!f)
+        f=themeFileSub(prefix, name, tmpStr, QTC_THEME_DIR4);
+
+    return f;
+}
+
 static void parseQtColors(char *line, int p)
 {
     int  n=-1;
@@ -325,6 +351,12 @@ static void parseQtColors(char *line, int p)
                 case 13:
                     setRgb(&qtSettings.colors[p][COLOR_TEXT_SELECTED], l);
                     break;
+                case 18:
+                    setRgb(&qtSettings.colors[p][COLOR_TOOLTIP], l);
+                    break;
+                case 19:
+                    setRgb(&qtSettings.colors[p][COLOR_TOOLTIP_TEXT], l);
+                    break;
                 default:
                     break;
             }
@@ -372,30 +404,30 @@ static int readRc(const char *rc, int rd, Options *opts, gboolean absolute, gboo
                 if(line[0]=='[')
                 {
                     if(qt4)
-                        if(0==memcmp(line, "[Qt]", 4))
+                        if(0==strncmp_i(line, "[Qt]", 4))
                             section=SECT_QT;
                         else
                             section=SECT_NONE;
                     else
-                        if(0==memcmp(line, "[Palette]", 9))
+                        if(0==strncmp_i(line, "[Palette]", 9))
                             section=SECT_PALETTE;
-                        else if(0==memcmp(line, "[General]", 9))
+                        else if(0==strncmp_i(line, "[General]", 9))
                             section=SECT_GENERAL;
-                        else if(0==memcmp(line, "[KDE]", 5))
+                        else if(0==strncmp_i(line, "[KDE]", 5))
                             section=SECT_KDE;
-                        else if(opts->mapKdeIcons && 0==memcmp(line, "[Icons]", 7))
+                        else if(opts->mapKdeIcons && 0==strncmp_i(line, "[Icons]", 7))
                             section=SECT_ICONS;
-                        else if(0==memcmp(line, "[Toolbar style]", 15))
+                        else if(0==strncmp_i(line, "[Toolbar style]", 15))
                             section=SECT_TOOLBAR_STYLE;
-                        else if(opts->mapKdeIcons && 0==memcmp(line, "[MainToolbarIcons]", 18))
+                        else if(opts->mapKdeIcons && 0==strncmp_i(line, "[MainToolbarIcons]", 18))
                             section=SECT_MAIN_TOOLBAR_ICONS;
-                        else if(opts->mapKdeIcons && 0==memcmp(line, "[SmallIcons]", 12))
+                        else if(opts->mapKdeIcons && 0==strncmp_i(line, "[SmallIcons]", 12))
                             section=SECT_SMALL_ICONS;
                         else
                             section=SECT_NONE;
                 }
                 else if (SECT_ICONS==section && rd&RD_ICONS && !(found&RD_ICONS) &&
-                         0==memcmp(line, "Theme=", 6))
+                         0==strncmp_i(line, "Theme=", 6))
                 {
                     char *eq=strstr(line, "=");
 
@@ -418,7 +450,7 @@ static int readRc(const char *rc, int rd, Options *opts, gboolean absolute, gboo
                     found|=RD_ICONS;
                 }
                 else if (SECT_SMALL_ICONS==section && rd&RD_SMALL_ICON_SIZE && !(found&RD_SMALL_ICON_SIZE) &&
-                         0==memcmp(line, "Size=", 5))
+                         0==strncmp_i(line, "Size=", 5))
                 {
                     char *eq=strstr(line, "=");
 
@@ -433,25 +465,25 @@ static int readRc(const char *rc, int rd, Options *opts, gboolean absolute, gboo
                     }
                 }
                 else if (SECT_TOOLBAR_STYLE==section && rd&RD_TOOLBAR_STYLE &&
-                         !(found&RD_TOOLBAR_STYLE) && 0==memcmp(line, "IconText=", 9))
+                         !(found&RD_TOOLBAR_STYLE) && 0==strncmp_i(line, "IconText=", 9))
                 {
                     char *eq=strstr(line, "=");
 
                     if(eq && ++eq)
                     {
-                        if(0==memcmp(eq, "IconOnly", 8))
+                        if(0==strncmp_i(eq, "IconOnly", 8))
                             qtSettings.toolbarStyle=GTK_TOOLBAR_ICONS;
-                        else if(0==memcmp(eq, "TextOnly", 8))
+                        else if(0==strncmp_i(eq, "TextOnly", 8))
                             qtSettings.toolbarStyle=GTK_TOOLBAR_TEXT;
-                        else if(0==memcmp(eq, "IconTextRight", 13))
+                        else if(0==strncmp_i(eq, "IconTextRight", 13))
                             qtSettings.toolbarStyle=GTK_TOOLBAR_BOTH_HORIZ;
-                        else if(0==memcmp(eq, "IconTextBottom", 14))
+                        else if(0==strncmp_i(eq, "IconTextBottom", 14))
                             qtSettings.toolbarStyle=GTK_TOOLBAR_BOTH;
                         found|=RD_TOOLBAR_STYLE;
                     }
                 }
                 else if (SECT_MAIN_TOOLBAR_ICONS==section && rd&RD_TOOLBAR_ICON_SIZE &&
-                         !(found&RD_TOOLBAR_ICON_SIZE) && 0==memcmp(line, "Size=", 5))
+                         !(found&RD_TOOLBAR_ICON_SIZE) && 0==strncmp_i(line, "Size=", 5))
                 {
                     char *eq=strstr(line, "=");
 
@@ -462,18 +494,19 @@ static int readRc(const char *rc, int rd, Options *opts, gboolean absolute, gboo
                     }
                 }
                 else if (SECT_KDE==section && rd&RD_BUTTON_ICONS && !(found&RD_BUTTON_ICONS) &&
-                         0==memcmp(line, "ShowIconsOnPushButtons=", 23))
+                         0==strncmp_i(line, "ShowIconsOnPushButtons=", 23))
                 {
                     char *eq=strstr(line, "=");
 
                     if(eq && ++eq)
                     {
-                        qtSettings.buttonIcons=0==memcmp(eq, "true", 4);
+                        qtSettings.buttonIcons=0==strncmp_i(eq, "true", 4);
                         found|=RD_BUTTON_ICONS;
                     }
                 }
-                else if(SECT_KDE==section && rd&RD_CONTRAST && !(found&RD_CONTRAST) &&
-                        0==memcmp(line, "contrast=", 9))
+                else if(rd&RD_CONTRAST && !(found&RD_CONTRAST) &&
+                         ( (!qt4 && SECT_KDE==section && 0==strncmp_i(line, "contrast=", 9)) ||
+                           ( qt4 && SECT_QT==section  && 0==strncmp_i(line, "KDE\\contrast=", 13))))
                 {
                     char *l=strchr(line, '=');
                     l++;
@@ -483,7 +516,7 @@ static int readRc(const char *rc, int rd, Options *opts, gboolean absolute, gboo
                     found|=RD_CONTRAST;
                 }
                 else if(SECT_GENERAL==section && rd&RD_LIST_COLOR && !(found&RD_LIST_COLOR) &&
-                        0==memcmp(line, "alternateBackground=", 20))
+                        0==strncmp_i(line, "alternateBackground=", 20))
                 {
                     sscanf(&line[20], "%d,%d,%d\n", &qtSettings.colors[PAL_ACTIVE][COLOR_LV].red,
                                                     &qtSettings.colors[PAL_ACTIVE][COLOR_LV].green,
@@ -494,32 +527,46 @@ static int readRc(const char *rc, int rd, Options *opts, gboolean absolute, gboo
 
                     found|=RD_LIST_COLOR;
                 }
+                else if(SECT_GENERAL==section && rd&RD_LIST_SHADE && !(found&RD_LIST_SHADE) &&
+                        0==strncmp_i(line, "shadeSortColumn=", 16))
+                {
+                    char *eq=strstr(line, "=");
+
+                    if(eq && ++eq)
+                    {
+                        qtSettings.shadeSortedList=0==strncmp_i(eq, "true", 4);
+                        found|=RD_LIST_SHADE;
+                    }
+                }
                 else if(( (!qt4 && SECT_PALETTE==section) || (qt4 && SECT_QT==section)) && rd&RD_ACT_PALETTE && !(found&RD_ACT_PALETTE) &&
-                        (qt4 ? 0==memcmp(line, "Palette\\active=", 15) : 0==memcmp(line, "active=", 7)))
+                        (qt4 ? 0==strncmp_i(line, "Palette\\active=", 15) : 0==strncmp_i(line, "active=", 7)))
                 {
                     parseQtColors(line, PAL_ACTIVE);
                     found|=RD_ACT_PALETTE;
                 }
 #ifdef QTC_READ_INACTIVE_PAL
                 else if(( (!qt4 && SECT_PALETTE==section) || (qt4 && SECT_QT==section)) && rd&RD_INACT_PALETTE && !(found&RD_INACT_PALETTE) &&
-                        (qt4 ? 0==memcmp(line, "Palette\\inactive=", 17) : 0==memcmp(line, "inactive=", 9)))
+                        (qt4 ? 0==strncmp_i(line, "Palette\\inactive=", 17) : 0==strncmp_i(line, "inactive=", 9)))
                 {
                     parseQtColors(line, PAL_INACTIVE);
                     found|=RD_INACT_PALETTE;
                 }
 #endif
-                else if (SECT_GENERAL==section && rd&RD_STYLE && !(found&RD_STYLE) && 0==memcmp(line, "style=", 6))
+                else if (((!qt4 && SECT_GENERAL==section) || (qt4 && SECT_QT==section)) &&
+                         rd&RD_STYLE && !(found&RD_STYLE)&& 0==strncmp_i(line, "style=", 6))
+
                 {
                     int len=strlen(line);
                     qtSettings.styleName=realloc(qtSettings.styleName, strlen(&line[6])+1);
                     if('\n'==line[len-1])
                         line[len-1]='\0';
                     strcpy(qtSettings.styleName, &line[6]);
+                    found|=RD_STYLE;
                 }
                 else if (( !qt4 && SECT_GENERAL==section && rd&RD_FONT && !(found&RD_FONT) &&
-                            0==memcmp(line, "font=", 5)) ||
-                         ( qt4 && SECT_QT & rd&RD_FONT && !(found&RD_FONT) &&
-                            0==memcmp(line, "font=\"", 6)) )
+                            0==strncmp_i(line, "font=", 5)) ||
+                         ( qt4 && SECT_QT==section && rd&RD_FONT && !(found&RD_FONT) &&
+                            0==strncmp_i(line, "font=\"", 6)) )
                 {
                     int   n=-1,
                           rc_weight=WEIGHT_NORMAL,
@@ -678,7 +725,7 @@ static int readRc(const char *rc, int rd, Options *opts, gboolean absolute, gboo
                     (int)size);
         }
 #ifdef QTC_DEBUG
-printf("REQUEST FONT: %s\n", qtSettings.font);
+        printf("REQUEST FONT: %s\n", qtSettings.font);
 #endif
     }
 
@@ -691,7 +738,8 @@ printf("REQUEST FONT: %s\n", qtSettings.font);
         qtSettings.toolbarStyle=GTK_TOOLBAR_ICONS;
     if(rd&RD_BUTTON_ICONS && !(found&RD_BUTTON_ICONS))
         qtSettings.buttonIcons=TRUE;
-
+    if(rd&RD_LIST_SHADE && !(found&RD_LIST_SHADE))
+        qtSettings.shadeSortedList=TRUE;
     return found;
 }
 
@@ -899,6 +947,13 @@ static char * getIconPath()
 
     strcat(path, "\"");
 
+    {
+    int plen=strlen(path);
+
+    if(path[plen - 1] == ':')
+        path[plen - 1] = '\0';
+    }
+
     return path;
 }
 
@@ -1163,7 +1218,7 @@ static void processMozillaApp(gboolean add_css, gboolean add_menu_colors, char *
 }
 #endif
 
-#ifdef QTC_ADD_EVENT_FILTER
+#ifdef QTC_ADD_EVENT_FILTER____DISABLED
 /* ... Taken from Qt engine ... */
 
 #include <gdk/gdkx.h>
@@ -1200,13 +1255,17 @@ static void qtcAddEventFilter() /* GdkWindow *widget) */
         /* Create a new window, and set the KDE_DESKTOP_WINDOW property on it
            This window will then receive events from KDE when the style changes */
 
-        GtkWindow *top=gtk_window_new(GTK_WINDOW_TOPLEVEL);
+        GtkWidget *top=gtk_window_new(GTK_WINDOW_TOPLEVEL);
 
         if(top && GTK_IS_WIDGET(top))
         {
             long data = 1;
 
             gtk_window_iconify(GTK_WINDOW(top));
+            gtk_window_set_decorated(GTK_WINDOW(top), FALSE);
+            gtk_window_set_keep_below(GTK_WINDOW(top), TRUE);
+            gtk_window_set_opacity(GTK_WINDOW(top), 100);
+            gtk_window_set_type_hint(GTK_WINDOW(top), GDK_WINDOW_TYPE_HINT_DOCK);
             gtk_widget_show(top);
             gtk_window_set_skip_taskbar_hint(GTK_WINDOW(top), TRUE);
             gtk_window_set_skip_pager_hint(GTK_WINDOW(top), TRUE);
@@ -1261,6 +1320,29 @@ static gboolean checkFileVersion(const char *fname, const char *versionStr, int
     return !diff;
 }
 
+static gboolean isMozApp(const char *app, const char *check)
+{
+    if(0==strcmp(app, check))
+        return TRUE;
+    else if(app==strstr(app, check))
+    {
+        int app_len=strlen(app),
+            check_len=strlen(check);
+
+        if(check_len+4 == app_len && 0==strcmp(&app[check_len], "-bin"))
+            return TRUE;
+
+        /* OK check for xulrunner-1.9 */
+        {
+        double dummy;
+        if(app_len>(check_len+1) && 1==sscanf(&app[check_len+1], "%f", &dummy))
+            return TRUE;
+        }
+    }
+
+    return FALSE;
+}
+
 static gboolean qtInit(Options *opts)
 {
     if(0==qt_refs++)
@@ -1288,8 +1370,16 @@ static gboolean qtInit(Options *opts)
             qtSettings.iconSizes.dndSize=32;
             qtSettings.iconSizes.btnSize=16;
             qtSettings.iconSizes.mnuSize=16;
-            qtSettings.iconSizes.dlgSize=22;
-            qtSettings.colors[PAL_ACTIVE][COLOR_LV].red=qtSettings.colors[PAL_ACTIVE][COLOR_LV].green=qtSettings.colors[PAL_ACTIVE][COLOR_LV].blue=0;
+            qtSettings.iconSizes.dlgSize=32;
+            qtSettings.colors[PAL_ACTIVE][COLOR_LV].red=
+                qtSettings.colors[PAL_ACTIVE][COLOR_LV].green=
+                qtSettings.colors[PAL_ACTIVE][COLOR_LV].blue=0;
+            qtSettings.colors[PAL_ACTIVE][COLOR_TOOLTIP_TEXT].red=
+                qtSettings.colors[PAL_ACTIVE][COLOR_TOOLTIP_TEXT].green=
+                qtSettings.colors[PAL_ACTIVE][COLOR_TOOLTIP_TEXT].blue=0;
+            qtSettings.colors[PAL_ACTIVE][COLOR_TOOLTIP_TEXT].red=0xFFFF;
+            qtSettings.colors[PAL_ACTIVE][COLOR_TOOLTIP_TEXT].green=0xFFFF;
+            qtSettings.colors[PAL_ACTIVE][COLOR_TOOLTIP_TEXT].blue=toGtkColor(192);
             qtSettings.styleName=NULL;
 
             lastRead=now;
@@ -1321,6 +1411,20 @@ static gboolean qtInit(Options *opts)
                 qtSettings.qt4=TRUE;
             }
 
+            /* Only for testing - allows me to simulate Qt's -style parameter. e.g start Gtk2 app as follows:
+
+                QTC_STYLE=qtc_klearlooks gtk-demo
+            */
+            {
+                const char *env=getenv("QTC_STYLE");
+
+                if(env)
+                {
+                    qtSettings.styleName=realloc(qtSettings.styleName, strlen(env));
+                    strcpy(qtSettings.styleName, env);
+                }
+            }
+
             /* Is the user using a non-default QtCurve style? */
             if(qtSettings.styleName && qtSettings.styleName==strstr(qtSettings.styleName, QTC_THEME_PREFIX))
             {
@@ -1349,9 +1453,12 @@ static gboolean qtInit(Options *opts)
             /* Check if we're firefox... */
             if((app=getAppName()))
             {
-                if((0==strcmp(app, "firefox-bin") || 0==strcmp(app, "thunderbird-bin") ||
-                    0==strcmp(app, "iceweasel-bin") ||
-                    0==strcmp(app, "swiftfox-bin") || 0==strcmp(app, "mozilla-thunderbird-bin")))
+                gboolean firefox=isMozApp(app, "firefox") || isMozApp(app, "iceweasel") ||
+                                 isMozApp(app, "swiftfox") || isMozApp(app, "xulrunner"),
+                         thunderbird=!firefox && isMozApp(app, "thunderbird"),
+                         mozThunderbird=!thunderbird && !firefox && isMozApp(app, "mozilla-thunderbird");
+
+                if(firefox || thunderbird || mozThunderbird)
                 {
 #ifdef QTC_MODIFY_MOZILLA
                     GdkColor *menu_col=SHADE_CUSTOM==opts->shadeMenubars
@@ -1363,14 +1470,18 @@ static gboolean qtInit(Options *opts)
                                                                TOO_DARK(*menu_col) ))
                         add_menu_colors=TRUE;
 
-                    if(0==strcmp(app, "firefox-bin") || 0==strcmp(app, "swiftfox-bin") || 0==strcmp(app, "iceweasel-bin"))
+                    if(firefox)
                         processMozillaApp(!opts->gtkButtonOrder, add_menu_colors, "firefox", TRUE);
-                    else if(0==strcmp(app, "thunderbird-bin"))
+                    else if(thunderbird)
                         processMozillaApp(!opts->gtkButtonOrder, add_menu_colors, "thunderbird", FALSE);
-                    else if(0==strcmp(app, "mozilla-thunderbird-bin"))
+                    else if(mozThunderbird)
                         processMozillaApp(!opts->gtkButtonOrder, add_menu_colors, "mozilla-thunderbird", FALSE);
 #endif
-                    qtSettings.app=GTK_APP_MOZILLA;
+                    qtSettings.app= (firefox && opts->newFirefox) ||
+                                    ((thunderbird || mozThunderbird) && opts->newThunderbird) ||
+                                    NULL!=getenv("QTC_NEW_MOZILLA")
+                                        ? GTK_APP_NEW_MOZILLA
+                                        : GTK_APP_MOZILLA;
                 }
                 else if(0==strcmp(app, "soffice.bin"))
                     qtSettings.app=GTK_APP_OPEN_OFFICE;
@@ -1382,15 +1493,20 @@ static gboolean qtInit(Options *opts)
                     qtSettings.app=GTK_APP_GIMP;
                 else if(0==strcmp(app, "java"))
                     qtSettings.app=GTK_APP_JAVA;
+                else if(0==strcmp(app, "evolution"))
+                    qtSettings.app=GTK_APP_EVOLUTION;
+                /*else if(0==strcmp(app, "eclipse"))
+                    qtSettings.app=GTK_APP_JAVA_SWT;*/
                 /*else if(app==strstr(app, "gaim"))
                     qtSettings.app=GTK_APP_GAIM;*/
             }
 
             /* Eclipse sets a application name, so if this is set then we're not a Swing java app */
-            if(GTK_APP_JAVA==qtSettings.app && g_get_application_name() && 0!=strcmp(g_get_application_name(), "<unknown>"))
-                qtSettings.app=GTK_APP_JAVA_SWT;
+            /*if(GTK_APP_JAVA==qtSettings.app && g_get_application_name() && 0!=strcmp(g_get_application_name(), "<unknown>"))
+                qtSettings.app=GTK_APP_JAVA_SWT;*/
 
-            /*if(GTK_APP_MOZILLA==qtSettings.app || GTK_APP_JAVA==qtSettings.app)*/
+            /*if(isMozilla() || GTK_APP_JAVA==qtSettings.app)*/
+            if(GTK_APP_JAVA!=qtSettings.app)
             {
                 /* KDE's "apply colors to non-KDE apps" messes up firefox, (and progress bar text) so need to fix this! */
                 /* ...and inactive highlight!!! */
@@ -1464,7 +1580,7 @@ static gboolean qtInit(Options *opts)
                 opts->shadeMenubars=SHADE_NONE;
 
             readRc(kdeGlobals(),
-                   (opts->mapKdeIcons ? RD_ICONS|RD_SMALL_ICON_SIZE : 0)|RD_TOOLBAR_STYLE|RD_TOOLBAR_ICON_SIZE|RD_BUTTON_ICONS|RD_LIST_COLOR,
+                   (opts->mapKdeIcons ? RD_ICONS|RD_SMALL_ICON_SIZE : 0)|RD_TOOLBAR_STYLE|RD_TOOLBAR_ICON_SIZE|RD_BUTTON_ICONS|RD_LIST_COLOR|RD_LIST_SHADE,
                     opts, TRUE, FALSE, FALSE);
 
             /* Tear off menu items dont seem to draw they're background, and the default background
@@ -1620,6 +1736,10 @@ static gboolean qtInit(Options *opts)
                 gtk_rc_parse_string(tmpStr);
             }
 */
+            /* For some reason Firefox 3beta4 goes mad if GtkComboBoxEntry::appears-as-list = 1 !!!! */
+            if(isMozilla())
+                gtk_rc_parse_string("style \"QtcMz\" { GtkComboBoxEntry::appears-as-list = 0 } class \"*\" style \"QtcMz\"");
+
             if(GTK_APP_MOZILLA==qtSettings.app || GTK_APP_JAVA==qtSettings.app)
                 opts->scrollbarType=SCROLLBAR_WINDOWS;
             else
@@ -1664,7 +1784,7 @@ static gboolean qtInit(Options *opts)
             }
 
             /* Set cursor colours... */
-            {
+            { /* C-Scope */
                 static const char *constStrFormat="style \"QtCCrsr\" "
                                                     "{ GtkWidget::cursor-color=\"#%02X%02X%02X\" "
                                                       "GtkWidget::secondary-cursor-color=\"#%02X%02X%02X\" } "
@@ -1678,7 +1798,94 @@ static gboolean qtInit(Options *opts)
                                                 qtSettings.colors[PAL_ACTIVE][COLOR_TEXT].green>>8,
                                                 qtSettings.colors[PAL_ACTIVE][COLOR_TEXT].blue>>8);
                 gtk_rc_parse_string(tmpStr);
-            }
+            } /* C-Scope */
+
+            if(!opts->gtkScrollViews && NULL!=gtk_check_version(2, 12, 0))
+                opts->gtkScrollViews=true;
+
+            { /* C-Scope */
+            bool doEffect=ROUND_FULL==opts->round && EFFECT_NONE!=opts->buttonEffect;
+            int  thickness=2;
+
+            if(doEffect)
+                gtk_rc_parse_string("style \"QtcEtch\" "
+                                    "{ xthickness = 3 ythickness = 3 } "
+                                    "style \"QtcEtchI\" "
+                                    "{ GtkCheckButton::indicator_size = 15 } "
+                                    "class \"*GtkRange\" style \"QtcEtch\" "
+                                    "class \"*GtkSpinButton\" style \"QtcEtch\" "
+                                    "class \"*GtkEntry\" style  \"QtcEtch\" "
+                                    "widget_class \"*Toolbar*Entry\" style \"QtcEtch\" "
+                                    "class \"*Button\" style \"QtcEtch\""
+                                    "class \"*GtkOptionMenu\" style \"QtcEtch\""
+                                    /*"class \"*GtkWidget\" style \"QtcEtchI\""*/);
+
+            if(!opts->gtkScrollViews)
+                gtk_rc_parse_string("style \"QtcSV\""
+                                    " { GtkScrolledWindow::scrollbar-spacing = 0 "
+                                      " GtkScrolledWindow::scrollbars-within-bevel = 1 } "
+                                    "class \"*GtkWidget\" style \"QtcSV\"");
+
+            /* Scrolled windows */
+            if(opts->squareScrollViews)
+                thickness=opts->gtkScrollViews ? 1 : 2;
+            else if(opts->sunkenScrollViews)
+                thickness=3;
+
+            { /* C-Scope */
+                static const char *constStrFormat="style \"QtcSVt\" "
+                                                    "{ xthickness = %d ythickness = %d } "
+                                                      "class \"*GtkScrolledWindow\" style \"QtcSVt\"";
+
+                tmpStr=(char *)realloc(tmpStr, strlen(constStrFormat)+1);
+                sprintf(tmpStr, constStrFormat, thickness, thickness);
+                gtk_rc_parse_string(tmpStr);
+            } /* C-Scope */
+
+            { /* C-Scope */
+                static const char *constStrFormat="style \"QtcPbar\" "
+                                                    "{ xthickness = %d ythickness = %d } "
+                                                      "widget_class \"*GtkProgressBar\" style \"QtcPbar\"";
+                int pthickness=opts->fillProgress
+                                ? doEffect
+                                    ? 2
+                                    : 1
+                                : doEffect
+                                    ? 3
+                                    : 2;
+
+                tmpStr=(char *)realloc(tmpStr, strlen(constStrFormat)+1);
+                sprintf(tmpStr, constStrFormat, pthickness, pthickness);
+                gtk_rc_parse_string(tmpStr);
+            } /* C-Scope */
+            } /* C-Scope 'doEffect' */
+
+            { /* C-Scope */
+                static const char *constStrFormat="style \"QtcTT\" "
+                                                    "{ xthickness = 4 ythickness = 4 bg[NORMAL] = \"#%02X%02X%02X\" fg[NORMAL] = \"#%02X%02X%02X\"} "
+                                                    "widget \"gtk-tooltips*\" style \"QtcTT\" "
+                                                    "widget \"gtk-tooltip*\" style \"QtcTT\"";
+
+                tmpStr=(char *)realloc(tmpStr, strlen(constStrFormat)+1);
+                sprintf(tmpStr, constStrFormat,
+                        toQtColor(qtSettings.colors[PAL_ACTIVE][COLOR_TOOLTIP_TEXT].red),
+                        toQtColor(qtSettings.colors[PAL_ACTIVE][COLOR_TOOLTIP_TEXT].green),
+                        toQtColor(qtSettings.colors[PAL_ACTIVE][COLOR_TOOLTIP_TEXT].blue),
+                        toQtColor(qtSettings.colors[PAL_ACTIVE][COLOR_TOOLTIP].red),
+                        toQtColor(qtSettings.colors[PAL_ACTIVE][COLOR_TOOLTIP].green),
+                        toQtColor(qtSettings.colors[PAL_ACTIVE][COLOR_TOOLTIP].blue));
+                gtk_rc_parse_string(tmpStr);
+            } /* C-Scope */
+
+            if(ROUND_FULL==opts->round && EFFECT_NONE!=opts->buttonEffect)
+                gtk_rc_parse_string("style \"QtCSwt\" { xthickness = 3 ythickness = 2 }"
+                                    "widget_class \"*.SwtFixed.GtkCombo.GtkButton\" style \"QtCSwt\""
+                                    "widget_class \"*.SwtFixed.GtkCombo.GtkEntry\" style \"QtCSwt\"");
+
+            if(opts->lighterPopupMenuBgnd && !opts->borderMenuitems)
+                gtk_rc_parse_string("style \"QtCM\" { xthickness=1 ythickness=1 }\n"
+                                    "class \"*GtkMenu\" style \"QtCM\"");
+
             if(tmpStr)
                 free(tmpStr);
         }
